*************************
Molecule Driver for Azure
*************************

Molecule driver Azure is a python plugin that allows to create Azure compute
resources to test Ansible roles.

Documentation
=============

Read the documentation and more at `molecule-driver-azure <https://github.com/redhat-sap/molecule-driver-azure>`_
